@@ -19,6 +19,7 @@
  */
 
 #include "GeoIP.h"
+#include "GeoIP_internal.h"
 
 static geoipv6_t IPV6_NULL;
 
@@ -44,6 +45,10 @@ static geoipv6_t IPV6_NULL;
 #include <stdint.h>     /* For uint32_t */
 #endif
 
+#if defined(_WIN32)
+#include "pread.h"
+#endif
+
 #ifdef _UNUSED
 #elif defined(__GNUC__)
 #define _UNUSED __attribute__ ((unused))
